@@ -78,16 +78,13 @@ def render(raw_config, environment=None):
     if not environment:
         environment = {}
     try:
-        substituted = template.substitute(environment)
+        substituted = template.substitute(**environment)
     except KeyError as err:
         raise exceptions.MissingEnvironment(err.args[0])
-    except AttributeError as err:
-        # gets the missing attr from the error message to result in the same
-        # message as a KeyError
-        raise exceptions.MissingEnvironment(err.args[0].split("'")[3])
     except ValueError:
         # Support "invalid" placeholders for lookup placeholders.
-        substituted = template.safe_substitute(environment)
+        # needs to pass a Dict for correct error handling by the built-in
+        substituted = template.safe_substitute(**environment)
 
     if not isinstance(substituted, text_type):
         substituted = substituted.decode('utf-8')
