@@ -1,13 +1,13 @@
-"""Stacker hook for cleaning up resources prior to CFN stack deletion."""
-
+"""CFNgin hook for cleaning up resources prior to CFN stack deletion."""
+# TODO move to runway.cfngin.hooks on next major release
 import logging
 
 from botocore.exceptions import ClientError
 
-from stacker.lookups.handlers import output as output_module
-from stacker.lookups.handlers import rxref as rxref_module
-from stacker.lookups.handlers import xref as xref_module
-from stacker.session_cache import get_session
+from ..cfngin.lookups.handlers.output import OutputLookup
+from ..cfngin.lookups.handlers.rxref import RxrefLookup
+from ..cfngin.lookups.handlers.xref import XrefLookup
+from ..cfngin.session_cache import get_session
 
 LOGGER = logging.getLogger(__name__)
 
@@ -21,13 +21,13 @@ def purge_bucket(context, provider, **kwargs):
     else:
         if kwargs.get('bucket_output_lookup'):
             value = kwargs['bucket_output_lookup']
-            handler = getattr(output_module, 'handler')
+            handler = OutputLookup.handle
         elif kwargs.get('bucket_rxref_lookup'):
             value = kwargs['bucket_rxref_lookup']
-            handler = getattr(rxref_module, 'handler')
+            handler = RxrefLookup.handle
         elif kwargs.get('bucket_xref_lookup'):
             value = kwargs['bucket_xref_lookup']
-            handler = getattr(xref_module, 'handler')
+            handler = XrefLookup.handle
         else:
             LOGGER.fatal('No bucket name/source provided.')
             return False
@@ -43,11 +43,11 @@ def purge_bucket(context, provider, **kwargs):
                 return True
             raise
 
-    bucket_name = handler(
-        value,
-        provider=provider,
-        context=context
-    )
+        bucket_name = handler(
+            value,
+            provider=provider,
+            context=context
+        )
 
     s3_resource = session.resource('s3')
     try:
